@@ -27,7 +27,7 @@ from .swagger_doc import is_public
 from .errors import ValidationError, GenericError, NotFoundError
 from .json_encoder import SAFRSFormattedResponse
 from .util import classproperty
-from .jsonapi_formatting import jsonapi_filter, jsonapi_filter_query, jsonapi_filter_list, jsonapi_sort, jsonapi_format_response, paginate
+from .jsonapi_formatting import jsonapi_filter_query, jsonapi_filter_list, jsonapi_sort, jsonapi_format_response, paginate
 
 
 class Resource(FRSResource):
@@ -245,7 +245,7 @@ class SAFRSRestAPI(Resource):
 
     def get(self, **kwargs):
         """
-            summary : Retrieve a {class_name} object
+            summary : Retrieve {class_name} instance
             description : Retrieve {class_name} from {collection_name}
             responses :
                 200 :
@@ -295,7 +295,7 @@ class SAFRSRestAPI(Resource):
             meta.update(dict(instance_meta=instance._s_meta()))
         else:
             # retrieve a collection, filter and sort
-            instances = jsonapi_filter(self.SAFRSObject)
+            instances = self.SAFRSObject.jsonapi_filter()
             instances = jsonapi_sort(instances, self.SAFRSObject)
             links, data, count = paginate(instances, self.SAFRSObject)
 
@@ -527,7 +527,7 @@ class SAFRSRestAPI(Resource):
             raise ValidationError("", status_code=HTTPStatus.METHOD_NOT_ALLOWED)
 
         instance = self.SAFRSObject.get_instance(id)
-        safrs.DB.session.delete(instance)
+        instance._s_delete()
 
         return {}, HTTPStatus.NO_CONTENT
 
@@ -758,17 +758,14 @@ class SAFRSRestRelationshipAPI(Resource):
 
         if data is None:
             # item removed from relationship => 202 accepted
-            # TODO: add response to swagger
-            # add meta?
-            response = {}, HTTPStatus.NO_CONTENT
+            data, code = {}, HTTPStatus.NO_CONTENT
         elif changed:
-            obj_data = self.get(**obj_args)
-            response = make_response(obj_data, HTTPStatus.OK)
+            return self.get(**obj_args)
         else:
             # Nothing changed, reflect the data
-            response = make_response(jsonify({"data": data}), HTTPStatus.OK)
+            data, code = {"data": data}, HTTPStatus.OK
 
-        return response
+        return make_response(jsonify(data), code)
 
     # Adding items to a relationship
     def post(self, **kwargs):
@@ -1038,7 +1035,7 @@ class SAFRSJSONRPCAPI(Resource):
         else:
             response = {"meta": {"result": result}}
 
-        return jsonify(response)  # 200 : default
+        return make_response(jsonify(response), HTTPStatus.OK)
 
 
 # pylint: disable=too-few-public-methods
