@@ -10,67 +10,12 @@ import sqlalchemy.orm.dynamic
 import sqlalchemy.orm.collections
 import safrs
 from flask import request
-from .base import is_jsonapi_attr, Included
+from .base import Included
+from .jsonapi_attr import is_jsonapi_attr
 from .errors import ValidationError, GenericError
 from .config import get_config, get_request_param
 
 
-def jsonapi_filter(safrs_object):
-    """
-        https://jsonapi.org/recommendations/#filtering
-        Apply the request.args filters to the object
-        :param safrs_object: the safrs class object that is queried
-        :return: sqla query object
-    """
-    # First check if a filter= URL query parameter has been used
-    # the SAFRSObject should've implemented a filter method or
-    # overwritten the _s_filter method to implement custom filtering
-    filter_args = get_request_param("filter")
-    if filter_args:
-        safrs_object_filter = getattr(safrs_object, "filter", None)
-        if isinstance(safrs_object, (list, sqlalchemy.orm.collections.InstrumentedList)):
-            # not implemented
-            result = safrs_object
-        elif callable(safrs_object_filter):
-            result = safrs_object_filter(filter_args)
-        else:
-            result = safrs_object._s_filter(filter_args)
-        return result
-
-    expressions = []
-    filters = get_request_param("filters", {})
-    if isinstance(safrs_object, (list, sqlalchemy.orm.collections.InstrumentedList)):
-        return safrs_object
-
-    for attr_name, val in filters.items():
-        if attr_name == "id":
-            return safrs_object._s_get_instance_by_id(val)
-        if attr_name not in safrs_object._s_jsonapi_attrs:
-            # validation failed: this attribute can't be queried
-            safrs.log.warning("Invalid filter {}".format(attr_name))
-            continue
-        else:
-            attr = safrs_object._s_jsonapi_attrs[attr_name]
-        if is_jsonapi_attr(attr):
-            # to do
-            safrs.log.debug("Filtering not implemented for {}".format(attr))
-        else:
-            expressions.append((attr, val))
-
-    if expressions:
-        _expressions = []
-        for column, val in expressions:
-            if hasattr(column, "in_"):
-                _expressions.append(column.in_(val.split(",")))
-            else:
-                safrs.log.warning("'{}.{}' is not a column ({})".format(safrs_object, column, type(column)))
-        result = safrs_object._s_query.filter(*_expressions)
-    else:
-        result = safrs_object._s_query
-
-    return result
-
-
 def jsonapi_filter_list(relation):
     """
         :param relation: InstrumentedList
@@ -85,7 +30,7 @@ def jsonapi_filter_list(relation):
             result.add(instance)
             continue
         pks = {col.name: getattr(instance, col.name) for col in instance.id_type.columns}
-        filter_query = jsonapi_filter(instance.__class__)
+        filter_query = instance.__class__.jsonapi_filter()
         result.update(filter_query.filter_by(**pks).all())  # this should only contain zero or one items
     return list(result)
 
@@ -98,7 +43,7 @@ def jsonapi_filter_query(object_query, safrs_object):
 
         Called when filtering a relationship query
     """
-    filter_query = jsonapi_filter(safrs_object)
+    filter_query = safrs_object.jsonapi_filter()
     result = object_query.intersect(filter_query)
     return result
 
@@ -181,8 +126,10 @@ def paginate(object_query, SAFRSObject=None):
 
     def get_link(count, limit):
         result = SAFRSObject._s_url if SAFRSObject else ""
+        ignore_args = "page[offset]", "page[limit]"
         result += "?" + "&".join(
-            ["{}={}".format(k, v) for k, v in request.args.items()] + ["page[offset]={}&page[limit]={}".format(count, limit)]
+            ["{}={}".format(k, v) for k, v in request.args.items() if k not in ignore_args]
+            + ["page[offset]={}&page[limit]={}".format(count, limit)]
         )
         return result
 
@@ -198,8 +145,8 @@ def paginate(object_query, SAFRSObject=None):
         limit = get_config("MAX_PAGE_LIMIT")
     if page_offset <= 0:
         page_offset = 0
-    if page_offset > get_config("MAX_PAGE_LIMIT"):
-        page_offset = get_config("MAX_PAGE_LIMIT")
+    if page_offset > get_config("MAX_PAGE_OFFSET"):
+        page_offset = get_config("MAX_PAGE_OFFSET")
     page_base = int(page_offset / limit) * limit
 
     # Counting may take > 1s for a table with millions of records, depending on the storage engine :|
@@ -248,6 +195,7 @@ def paginate(object_query, SAFRSObject=None):
 
     if isinstance(object_query, (list, sqlalchemy.orm.collections.InstrumentedList)):
         instances = object_query[page_offset : page_offset + limit]
+
     elif isinstance(object_query, dict):
         # (might happen when using a custom filter)
         instances = object_query
