@@ -2,7 +2,7 @@ import logging
 import os
 import sys
 from flask_swagger_ui import get_swaggerui_blueprint
-from flask import Flask
+from flask import Flask, g
 from flask.json import JSONEncoder
 from flask_sqlalchemy import SQLAlchemy
 from .request import SAFRSRequest
@@ -48,6 +48,12 @@ def SAFRSAPI(app, host="localhost", port=5000, prefix="", description="SAFRSAPI"
     def handle_invalid_usage():
         return
 
+    @app.before_request
+    def init_ja_data():
+        # ja_data holds all data[] that will be encoded
+        g.ja_data = set()
+        g.ja_included = set()
+
     api.init_app(app)
     return api
 
@@ -62,6 +68,7 @@ class SAFRS:
 
     # Configuration settings, these can be overridden in config.py
     MAX_PAGE_LIMIT = 250
+    MAX_PAGE_OFFSET = 2 ** 31
     ENABLE_RELATIONSHIPS = True
     ENABLE_METHODS = True
     LOGLEVEL = logging.WARNING
